@@ -1,7 +1,10 @@
 # Solution found there:
 # http://stackoverflow.com/questions/11960079/padded-fit-with-easy-thumbnails
 
-import ImageChops
+try:
+    from PIL import ImageChops  # Pillow >= 2.1.0
+except ImportError:
+    import ImageChops  # Pillow < 2.1.0 & PIL
 
 
 def pad_image(image, **kwargs):
